==> haskell-hpack-0.35.2-191-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hpack
version:              0.35.2
visibility:           public
id:                   hpack-0.35.2-En9sps3rqEW3pLNRqs7o1Q
key:                  hpack-0.35.2-En9sps3rqEW3pLNRqs7o1Q
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/hpack#readme
synopsis:             A modern format for Haskell packages
description:          See README at <https://github.com/sol/hpack#readme>
category:             Development
abi:                  7c3306cd1835e40ad04f1a584b83dcf2
exposed:              True
exposed-modules:
    Hpack Hpack.Config Hpack.Error Hpack.Render Hpack.Yaml

hidden-modules:
    Data.Aeson.Config.FromValue Data.Aeson.Config.Key
    Data.Aeson.Config.KeyMap Data.Aeson.Config.Parser
    Data.Aeson.Config.Types Data.Aeson.Config.Util Hpack.CabalFile
    Hpack.Defaults Hpack.Haskell Hpack.License Hpack.Module
    Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
    Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
    Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
    Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
    Hpack.Util Imports Path Paths_hpack

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hpack-0.35.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hpack-0.35.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hpack-0.35.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hpack
hs-libraries:         HShpack-0.35.2-En9sps3rqEW3pLNRqs7o1Q
depends:
    Cabal-3.8.1.0 Glob-0.10.2-EuwNl6auLfF2yBtICGqk0s
    aeson-2.1.2.1-6acn88DzD1XA00qNRJAJcm base-4.17.2.1
    bifunctors-5.6-HNZgtrgMAz0JlHnhYpVgvx bytestring-0.11.5.3
    containers-0.6.7 cryptonite-0.30-82MvlXQwHgnJBRUwbtYUqj
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    http-client-0.7.17-9hjKpmcLdDxAkVwiCjuuk8
    http-client-tls-0.3.6.4-CBYdAYN8SE828XZuyCc2Cg
    http-types-0.12.4-8YA833LldYRCKJA3UrGcNq
    infer-license-0.2.0-Fw6sHORgHEZDUDTKIllTpS pretty-1.1.3.6
    scientific-0.3.7.0-EYP4lwU6ELFEdSU4sCeddu text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv
    yaml-0.11.11.2-9fO0ispisTfKsrkFOWalV3

haddock-interfaces:   /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html:         /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hpack-0.35.2-192-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hpack
version:              0.35.2
visibility:           public
id:                   hpack-0.35.2-CxwnDD57OchCAnb7eTltOS
key:                  hpack-0.35.2-CxwnDD57OchCAnb7eTltOS
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/hpack#readme
synopsis:             A modern format for Haskell packages
description:          See README at <https://github.com/sol/hpack#readme>
category:             Development
abi:                  df6283a861edd5495a6f9a4d5b7aa7fe
exposed:              True
exposed-modules:
    Hpack Hpack.Config Hpack.Error Hpack.Render Hpack.Yaml

hidden-modules:
    Data.Aeson.Config.FromValue Data.Aeson.Config.Key
    Data.Aeson.Config.KeyMap Data.Aeson.Config.Parser
    Data.Aeson.Config.Types Data.Aeson.Config.Util Hpack.CabalFile
    Hpack.Defaults Hpack.Haskell Hpack.License Hpack.Module
    Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
    Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
    Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
    Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
    Hpack.Util Imports Path Paths_hpack

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hpack-0.35.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hpack-0.35.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hpack-0.35.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hpack
hs-libraries:         HShpack-0.35.2-CxwnDD57OchCAnb7eTltOS
depends:
    Cabal-3.8.1.0 Glob-0.10.2-EuwNl6auLfF2yBtICGqk0s
    aeson-2.1.2.1-LDBL5bcX1HC79scYyh3opi base-4.17.2.1
    bifunctors-5.6-H5gLaZGTtKN1h3rKcuS2CV bytestring-0.11.5.3
    containers-0.6.7 cryptonite-0.30-82MvlXQwHgnJBRUwbtYUqj
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    http-client-0.7.17-39vQCRHDS8Y4AZkwpcxUyW
    http-client-tls-0.3.6.4-8CeCL7zDXbKxhjkugWal5
    http-types-0.12.4-3FyJu2Ux8ftJoanRheHyWI
    infer-license-0.2.0-Fw6sHORgHEZDUDTKIllTpS pretty-1.1.3.6
    scientific-0.3.7.0-EYP4lwU6ELFEdSU4sCeddu text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv
    yaml-0.11.11.2-7NEgW6E2pbYEs4sf4NTDIA

haddock-interfaces:   /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html:         /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
